==> haskell-primes-0.2.1.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-primes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: primes
version: 0.2.1.0
id: primes-0.2.1.0-4yl4879BvB2BN6PZhDdStZ
key: primes-0.2.1.0-4yl4879BvB2BN6PZhDdStZ
license: BSD3
maintainer: Sebastian Fischer
stability: experimental
homepage: http://github.com/sebfisch/primes
synopsis: Efficient, purely functional generation of prime numbers
description:
    This Haskell library provides an efficient lazy wheel sieve for
    prime generation inspired by /Lazy wheel sieves and spirals of/
    /primes/ by Colin Runciman and /The Genuine Sieve of Eratosthenes/
    by Melissa O'\''Neil.
category: Algorithms, Numerical
author: Sebastian Fischer
exposed: True
indefinite: False
exposed-modules:
    Data.Numbers.Primes
abi: 45bcffec8b6d32ec53481dc9ae01783e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/primes-0.2.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/primes-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/primes-0.2.1.0
hs-libraries: HSprimes-0.2.1.0-4yl4879BvB2BN6PZhDdStZ
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-primes/html/primes.haddock
haddock-html: /usr/share/doc/haskell-primes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primes-0.2.1.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-primes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: primes
version: 0.2.1.0
id: primes-0.2.1.0-DucHvFsSuMZGOrOqeezksH
key: primes-0.2.1.0-DucHvFsSuMZGOrOqeezksH
license: BSD-3-Clause
maintainer: Sebastian Fischer
author: Sebastian Fischer
stability: experimental
homepage: http://github.com/sebfisch/primes
synopsis: Efficient, purely functional generation of prime numbers
description:
    This Haskell library provides an efficient lazy wheel sieve for
    prime generation inspired by /Lazy wheel sieves and spirals of/
    /primes/ by Colin Runciman and /The Genuine Sieve of Eratosthenes/
    by Melissa O'\''Neil.
category: Algorithms, Numerical
abi: b96b585179c78ff7931d149044d1504d
exposed: True
exposed-modules:
    Data.Numbers.Primes
import-dirs: /usr/lib/ghc-8.4.2/site-local/primes-0.2.1.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/primes-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/primes-0.2.1.0
hs-libraries: HSprimes-0.2.1.0-DucHvFsSuMZGOrOqeezksH
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-primes/html/primes.haddock
haddock-html: /usr/share/doc/haskell-primes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
